<?php
	/***************************************/
	//
	//
	// PHP Live! Support
	//
	// https://www.phplivesupport.com
	//
	/***************************************/
	if ( defined( 'API_Util_LDAP' ) ) { return ; }	
	define( 'API_Util_LDAP', true ) ;

	$LDAP_ERROR = "" ;
	FUNCTION Util_LDAP_connect()
	{
		global $ldap_array ; global $LDAP_ERROR ;
		if ( !isset( $ldap_array ) || !isset( $ldap_array["server"] ) )
			return "LDAP configuration not found. [e1]" ;

		set_error_handler('Util_LDAP_error_handler') ;
		$ldap_connection = ldap_connect( $ldap_array["server"] ) ;
		restore_error_handler() ;

		if ( !$LDAP_ERROR )
		{
			$ldap_array["con"] = $ldap_connection ;

			ldap_set_option( $ldap_array["con"], LDAP_OPT_PROTOCOL_VERSION, 3 ) ;
			ldap_set_option( $ldap_array["con"], LDAP_OPT_REFERRALS, 0 ) ; // better security to disable

			set_error_handler('Util_LDAP_error_handler') ;
			$result = @ldap_bind( $ldap_array["con"], "uid=".$ldap_array["login"].",ou=Users,".$ldap_array["basedn"], $ldap_array["password"] ) ;
			restore_error_handler() ;

			if ( $result )
			{
				return "" ; // empty error = success
			}
			else
			{
				if ( preg_match( "/Invalid credentials/i", $LDAP_ERROR ) )
					return "The LDAP 'Base DN', LDAP 'Login' or the LDAP 'Password' is incorrect." ;
				else
					return $LDAP_ERROR ;
			}
		} else { return "Could not connect to LDAP server.  The 'Server' is incorrect." ; }
	}

	FUNCTION Util_LDAP_search( $login, $password )
	{
		global $ldap_array ; global $LDAP_ERROR ;
		if ( !isset( $ldap_array ) || !isset( $ldap_array["con"] ) || !$ldap_array["con"] )
			return "LDAP configuration not found. [e2]" ;
		else if ( !$login )
			return "LDAP Login must be provided." ;

		$result = ldap_search( $ldap_array["con"], $ldap_array["basedn"], "uid=" . $login ) ;
		$userinfo = @ldap_get_entries( $ldap_array["con"], $result ) ;
		$found = ldap_count_entries( $ldap_array["con"], $result ) ; // contains number of results (should be 1 if found)
		if ( $found )
		{
			if ( $found > 1 ) { return "Multiple users with login ($login) found.  Login should be unique." ; }
			else if ( $found && is_array( $userinfo[0] ) )
			{
				if ( !$password )
					return $userinfo[0] ;
				else if ( isset( $userinfo[0]['dn'] ) )
				{
					$userdn = $userinfo[0]['dn'] ;
					set_error_handler('Util_LDAP_error_handler') ;
					$result = @ldap_bind( $ldap_array["con"], $userdn, $password ) ;
					restore_error_handler() ;
					if ( $result )
						return $userinfo[0] ;
					else
						return $LDAP_ERROR ;
				} else { return "Invalid login or password." ; }
			} else { return "Error parsing user information." ; }
		} else { return "LDAP user ($login) not found." ; }
	}

	FUNCTION Util_LDAP_login( &$dbh, $token_pass, $login, $password )
	{
		global $ldap_array ; global $LDAP_ERROR ;
		$opinfo = Array() ;
		if ( $login )
		{
			$opinfo = Ops_get_ext_OpInfoByLogin( $dbh, $login ) ;
			if ( isset( $opinfo["opID"] ) )
			{
				$error = Util_LDAP_connect() ;
				if ( !$error )
				{
					$userinfo = Util_LDAP_search( $login, $password ) ;
					if ( is_array( $userinfo ) && isset( $userinfo['cn'] ) )
					{
						$password = md5( $opinfo["password"].$token_pass ) ;
					} else { $opinfo = Array() ; }
				} Util_LDAP_close() ;

				if ( $error )
					return Array( Array(), $error ) ;
			}
		}
		if ( !isset( $opinfo["opID"] ) ) { $password = "" ; }
		return Array( $opinfo, $password ) ;
	} FUNCTION Util_LDAP_error_handler($errno, $errstr) { global $LDAP_ERROR ; $LDAP_ERROR = $errstr ; }

	FUNCTION Util_LDAP_close()
	{
		global $ldap_array ;
		if ( !isset( $ldap_array ) || !isset( $ldap_array["con"] ) || !$ldap_array["con"] )
			return false ;
		ldap_close( $ldap_array["con"] ) ;
		return true ;
	}
?>