<?php
	/***************************************/
	//
	//
	// PHP Live! Support
	//
	// https://www.phplivesupport.com
	//
	/***************************************/

	/***************************************/
	// DO NOT MODIFY THIS FILE.  RATHER, copy this file to a new file and modify that file.
	/***************************************/
	//
	// Usage:
	// % php cron.php {email} {span} {value}
	//
	// email = (required) The email address the output is emailed to
	// span = (required) Example: A value of 7 would output previous 7 days of data.
	// value = (optional)
	//        1 = the first value (typically Yes)
	//        0 = the second value (typically No)
	//        * all responses will output if value is not provided
	//
	// Example command line:
	// % php cron.php someone@somewhere.com 7 1
	// The above will output previous 7 days of stats that match response of 1
	// The output will be emailed to someone@somewhere.com
	//
	// Example:
	// % php cron.php someone@somewhere.com 7
	// The above will output previous 7 days of data, all responses
	// The output will be emailed to someone@somewhere.com
	//
	/***************************************/

	if ( php_sapi_name() == "cli" )
	{
		$now = time() ;
		$month = date( "n", $now ) ;
		$day = date( "j", $now ) ;
		$year = date( "Y", $now ) ;

		$email = ( isset( $argv[1] ) ) ? $argv[1] : "null" ;

		// example: $span value of -7 would extract for previous week (7 days)
		// example: $span value of 3 would extract 
		$span = ( isset( $argv[2] ) ) ? $argv[2] : "null" ;

		$value = ( isset( $argv[3] ) ) ? $argv[3] : 10 ;

		// always use "export" action.  the "cron" action only outputs timestamp
		$action = ( isset( $argv[4] ) && ( $argv[4] == "cron" ) ) ? "cron" : "export" ;

		if ( ( $email == "null" ) || !preg_match( "/@/", $email ) )
		{
			print "Error: Invalid email format." ;
		}
		else if ( !is_numeric( $span ) )
		{
			print "Error: Span value must be a number." ;
		}
		else
		{
			if ( defined('PHP_MAJOR_VERSION') && PHP_MAJOR_VERSION >= 7 )
				$dir_path = dirname( __DIR__, 3 ) ;
			else
				$dir_path = realpath( __DIR__ . "/../../../" ) ;

			if ( !is_file( "$dir_path/web/config.php" ) ){ print "Error: Could not locate $dir_path/web/config.php file." ; }
			else
			{
				include_once( "$dir_path/web/config.php" ) ;
				include_once( "$CONF[DOCUMENT_ROOT]/API/Util_Format.php" ) ;
				include_once( "$CONF[DOCUMENT_ROOT]/API/Util_Functions_itr.php" ) ;
				include_once( "$CONF[DOCUMENT_ROOT]/API/".Util_Format_Sanatize($CONF["SQLTYPE"], "ln") ) ;
				include_once( "$CONF[DOCUMENT_ROOT]/API/Util_Email.php" ) ;
				include_once( "$CONF[DOCUMENT_ROOT]/API/Depts/get.php" ) ;

				$akey = md5( $CONF['BASE_URL'].$CONF['API_KEY'] ) ;
				$url = $CONF["BASE_URL"] ;
				if ( !preg_match( "/^http/", $url ) ) { $url = "http:$url" ; }

				$request = curl_init() ;
				curl_setopt( $request, CURLOPT_URL,"$url/addons/emarketing/export.php" ) ;
				curl_setopt( $request, CURLOPT_RETURNTRANSFER, true ) ;
				curl_setopt( $request, CURLOPT_CUSTOMREQUEST, "POST" ) ;
				curl_setopt( $request, CURLOPT_POSTFIELDS, array( "action"=>"$action", "format"=>"csv", "akey"=>"$akey", "month"=>"$month", "day"=>"$day", "year"=>"$year", "value"=> "$value", "span"=>"$span" ) ) ;
				if ( !isset( $VARS_SET_VERIFYPEER ) || ( $VARS_SET_VERIFYPEER == 1 ) )
				{
					curl_setopt( $request, CURLOPT_SSL_VERIFYPEER, true ) ;
					curl_setopt( $request, CURLOPT_CAINFO, "$CONF[DOCUMENT_ROOT]/mapp/API/cacert.pem" ) ;
				}
				else { curl_setopt( $request, CURLOPT_SSL_VERIFYPEER, false ) ; }
				$response = curl_exec( $request ) ;
				curl_close( $request ) ;

				$departments = Depts_get_AllDepts( $dbh ) ;
				for ( $c = 0; $c < count( $departments ); ++$c )
				{
					$deptinfo = $departments[$c] ;
					if ( $deptinfo["smtp"] )
					{
						$smtp_array = unserialize( Util_Functions_itr_Decrypt( $CONF["SALT"], $deptinfo["smtp"] ) ) ;
						break 1 ;
					}
				}

				$name = "Cron" ;
				$subject = "Cron: Email Marketing Responses [ ".date( "M j, Y ($VARS_TIMEFORMAT)", $now )." ]" ;
				$message = $response ;
				$filename = "" ;

				if ( is_dir( $CONF["ATTACH_DIR"] ) )
				{
					$filename = "Responses_{$month}_{$day}_{$year}_".md5( $subject ) . ".csv" ;
					file_put_contents( "$CONF[ATTACH_DIR]/$filename", $message ) ;
				}

				$error = Util_Email_SendEmail( $name, $email, $name, $email, $subject, $message, $filename ) ;
				if ( $filename && is_file( "$CONF[ATTACH_DIR]/$filename" ) )
					@unlink( "$CONF[ATTACH_DIR]/$filename" ) ;

				if ( !$error )
					print 1 ;
				else
					print $error ;
			}
		}
	}
	else
	{
		print "Error: Invalid access." ;
	}
?>